=================
Alarms and Events
=================

.. toctree::
    :maxdepth: 2
    :caption: Contents:

Overview
--------

The Alarm/Event screen displays the alarms and events on the network.
From this page, the alarms and events can be filtered, downloaded, and printed.

The Alarms/Events screen can be set to **Live** mode which updates the list
in real time.

A maximum of 5000 Alarms or Events will be loaded.

The columns displayed in the Alarms/Events screen is customisable.


.. image:: alarms_events_screen.png
    :align: center

View the Alarms/Events Screen
--------------------------------

Click on the **Alarms/Events** in the navigation bar.

.. image:: alarms_button.png
    :align: center

Filter the Alarms/Events
------------------------

#. Click on the **Filter** button.

.. image:: filter_button.png
    :align: center

----

The **Events Filter** popup will appear.

#. Select which attributes to filter the list by.
#. Click **Apply**.


.. image:: filter_popup.png
    :align: center

.. note::
    Discard your changes with the **Reset Defaults** button.

Configure the Columns
---------------------

#. Click the **Columns** button.

.. image:: columns.png
    :align: center

----

#. Add or remove columns from the field.
#. Click **Apply**.

.. image:: events_column.png
    :align: center

.. note:: Discard changes by clicking **Reset Defaults**.


Download the Alarms/Events
--------------------------

#. Click on **Download**

.. image:: download_button.png
    :align: center

----

#. Enter a name for the file.
#. Click **Save**.

.. image:: save.png
    :align: center

A CSV file will be created in the folder of your choice.

Toggle Options
--------------
.. image:: options_toggle.png
    :align: center

Toggle **Alarms only**
``````````````````````

Toggling this button will cause only **Alarms** to be displayed in the table.

Toggle **Live**
```````````````

Toggling this button will display **live updates** to the Alarms/Events table.

.. note:: Date range filtering is disabled when "Live" is enabled





